==> nextcloud-app-news-18.2.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/news/l10n/ca.js <==
OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "La sol·licitud ha fallat, la connexió de xarxa no està disponible!",
    "Request unauthorized. Are you logged in?" : "Sol·licitud no autoritzada. Heu iniciat la sessió?",
    "Token expired or app not enabled! Reload the page!" : "El Token està caducat o l'aplicació no està activada! Torneu a carregar la pàgina!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Error intern servidor! Consulteu el fitxer data/nextcloud.log per obtenir informació addicional!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "La sol·licitud ha fallat, Nextcloud és actualment en mode de manteniment!",
    "Unread articles" : "Articles sense llegir",
    "News" : "Notí­cies",
    "Shared with me" : "Compartit amb mi",
    "An RSS/Atom feed reader" : "Un lector de notícies RSS/Atom",
    "Use system cron for updates" : "Feu servir el sistema cron per a les actualitzacions",
    "Purge interval" : "Interval de purga",
    "Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored." : "Nombre mí­nim de segons abans que les fonts i carpetes eliminades siguin eliminades definitivament de la base de dades; valors per sota de 60 segons seran ignorats.",
    "Maximum read count per feed" : "Màxim nombre de lectures per font",
    "Maximum redirects" : "Màxim de redirigits",
    "How many redirects the feed fetcher should follow." : "Quantes redireccions hauria de suportar el descarregador de fonts.",
    "Feed fetcher timeout" : "Temps d'espera exhaurit per a la descàrrega de la font",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Nombre màxim de segons per esperar que carregui una font de RSS o Atom; si pren més temps, l'actualització serà cancel·lada.",
    "Explore Service URL" : "Explora l'URL del Servei",
    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "En cas d'haver-se emplenat, la URL d'aquest servei serà consultada per mostrar les fonts de la secció explorar fonts. Per tornar al servei d'exploració integrat, deixi aquest camp buit.",
    "Update interval" : "Interval d'actualització",
    "Interval in seconds in which the feeds will be updated." : "Interval en segons en què s'actualitzaran les fonts de continguts.",
    "Download" : "Baixa",
    "Close" : "Tanca",
    "Subscribe to" : "Subscriu a",
    "No articles available" : "No hi ha articles disponibles",
    "No unread articles available" : "No hi ha articles disponibles sense llegir",
    "Open website" : "Obre el lloc web",
    "Star article" : "Destaca l'article",
    "Unstar article" : "Deixa de destacar l'article",
    "Keep article unread" : "Manté l'article com a no llegit",
    "Remove keep article unread" : "Elimineu mantenir l'article no llegit",
    "Share" : "Compartir",
    "Username" : "Nom d'usuari",
    "by" : "per",
    "from" : "des de",
    "Play audio" : "Reprodueix l'àudio",
    "Download audio" : "Descarrega l'àudio",
    "Download video" : "Descarrega el vídeo",
    "Keyboard shortcut" : "Drecera de teclat",
    "Description" : "Descripció",
    "right" : "dreta",
    "Jump to next article" : "Vés al proper article",
    "left" : "esquerra",
    "Jump to previous article" : "Vés a l'article anterior",
    "Toggle star article" : "Commuta l'article com a destacat",
    "Star article and jump to next one" : "Destaca l'article i vés al següent",
    "Toggle keep current article unread" : "Commuta mantenir de l’article actual com a no llegit",
    "Open article in new tab" : "Obre l'article a una pestanya nova",
    "Toggle expand article in compact view" : "Commuta expandir l'article a una vista compacta",
    "Refresh" : "Refresca",
    "Load next feed" : "Carrega la font següent",
    "Load previous feed" : "Carrega la font anterior",
    "Load previous folder" : "Carrega la carpeta anterior",
    "Load next folder" : "Carrega la carpeta següent",
    "Scroll to active navigation entry" : "Desplaça per activar l'entrada de navegació",
    "Mark current article's feed/folder read" : "Marca com a llegida la font/carpeta de l'article actual",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "S'ha detectat el mode Ajax o webcron. Les vostres fonts no s'actualitzaran!",
    "How to set up the operating system cron" : "Com configurar el cron del sistema operatiu",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Instal·leu i configureu un actualitzador en paral·lel més ràpid que faci servir l'API d'actualització de l'aplicació de Notí­cies",
    "Subscribe" : "Subscriu",
    "Web address" : "Adreça web",
    "Feed exists already!" : "La font ja existeix!",
    "Folder" : "Carpeta",
    "No folder" : "Sense carpeta",
    "New folder" : "Carpeta nova",
    "Folder name" : "Nom de la carpeta",
    "Go back" : "Torna enrere",
    "Folder exists already!" : "La carpeta ja existeix!",
    "Credentials" : "Credencials",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Les credencials d’Autenticació Bàsica d'HTTP s’han d’emmagatzemar sense xifrar. Tothom que tingui accés al servidor o a la base de dades hi podrà accedir!",
    "Password" : "Contrasenya",
    "New Folder" : "Nova carpeta",
    "Create" : "Crea",
    "Explore" : "Explora",
    "Update failed more than 50 times" : "L'actualització ha fallat més de 50 vegades",
    "Deleted feed" : "S'ha suprimit la font",
    "Undo delete feed" : "Desfés la supressió de la font",
    "Rename" : "Canvia el nom",
    "Menu" : "Menú",
    "Mark read" : "Marca com a llegit",
    "Unpin from top" : "Desancora-ho de la part superior",
    "Pin to top" : "Ancora-ho a la part superior",
    "Newest first" : "Més nou primer",
    "Oldest first" : "Més antic primer",
    "Default order" : "Ordre per defecte",
    "Enable full text" : "Activa el text complet",
    "Disable full text" : "Desactiva el text complet",
    "Unread updated" : "Actualització no llegida",
    "Ignore updated" : "Ignora l'actualització",
    "Open feed URL" : "Obre l'URL del canal",
    "Delete" : "Suprimeix",
    "Dismiss" : "Rebutja",
    "Collapse" : "Replega",
    "Deleted folder" : "Carpeta suprimida",
    "Undo delete folder" : "Desfés la supressió de la carpeta",
    "Starred" : "Destacats",
    "All articles" : "Tots els articles",
    "Settings" : "Paràmetres",
    "Disable mark read through scrolling" : "Desactiva la marca de lectura mitjançant el desplaçament",
    "Compact view" : "Vista compacta",
    "Expand articles on key navigation" : "Amplia els articles sobre la navegació per tecles",
    "Show all articles" : "Mostra tots els articles",
    "Reverse ordering (oldest on top)" : "Ordre invers (més antic a la part superior)",
    "Subscriptions (OPML)" : "Subscripcions (OPML)",
    "Import" : "Importa",
    "Export" : "Exporta",
    "Error when importing: File does not contain valid OPML" : "S'ha produït un error mentre s'importava: el fitxer no conté OPML vàlid",
    "Error when importing: OPML is does neither contain feeds nor folders" : "S'ha produït un error mentre s'importava: OPML no conté ni fonts ni carpetes",
    "Unread/Starred Articles" : "Articles no llegits/destacats",
    "Error when importing: file does not contain valid JSON" : "S'ha produït un error mentre s'importava: el fitxer no conté un JSON vàlid",
    "Help" : "Ajuda",
    "Keyboard shortcuts" : "Dreceres de teclat",
    "Documentation" : "Documentació",
    "Report a bug" : "Informa d'un error"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-news-21.1.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/news/l10n/ca.js <==
OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "La sol·licitud ha fallat, la connexió de xarxa no està disponible!",
    "Request unauthorized. Are you logged in?" : "Sol·licitud no autoritzada. Heu iniciat la sessió?",
    "Token expired or app not enabled! Reload the page!" : "El Token està caducat o l'aplicació no està activada! Torneu a carregar la pàgina!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Error intern servidor! Consulteu el fitxer data/nextcloud.log per obtenir informació addicional!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "La sol·licitud ha fallat, Nextcloud és actualment en mode de manteniment!",
    "Unread articles" : "Articles sense llegir",
    "News" : "Notí­cies",
    "Shared with me" : "Compartit amb mi",
    "An RSS/Atom feed reader" : "Un lector de notícies RSS/Atom",
    "Last job ran {relativeTime}." : "L'última tasca es va executar {relativeTime}.",
    "Use system cron for updates" : "Feu servir el sistema cron per a les actualitzacions",
    "Maximum read count per feed" : "Màxim nombre de lectures per font",
    "Maximum redirects" : "Màxim de redirigits",
    "How many redirects the feed fetcher should follow." : "Quantes redireccions hauria de suportar el descarregador de fonts.",
    "Feed fetcher timeout" : "Temps d'espera exhaurit per a la descàrrega de la font",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Nombre màxim de segons per esperar que carregui una font de RSS o Atom; si pren més temps, l'actualització serà cancel·lada.",
    "Explore Service URL" : "Explora l'URL del Servei",
    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "En cas d'haver-se emplenat, la URL d'aquest servei serà consultada per mostrar les fonts de la secció explorar fonts. Per tornar al servei d'exploració integrat, deixi aquest camp buit.",
    "Update interval" : "Interval d'actualització",
    "Interval in seconds in which the feeds will be updated." : "Interval en segons en què s'actualitzaran les fonts de continguts.",
    "Download" : "Baixa",
    "Close" : "Tanca",
    "Subscribe to" : "Subscriu a",
    "No articles available" : "No hi ha articles disponibles",
    "No unread articles available" : "No hi ha articles disponibles sense llegir",
    "Open website" : "Obre el lloc web",
    "Star article" : "Destaca l'article",
    "Unstar article" : "Deixa de destacar l'article",
    "Keep article unread" : "Manté l'article com a no llegit",
    "Remove keep article unread" : "Elimineu mantenir l'article no llegit",
    "Share" : "Compartir",
    "Username" : "Nom d'usuari",
    "by" : "per",
    "from" : "des de",
    "Play audio" : "Reprodueix l'àudio",
    "Download audio" : "Descarrega l'àudio",
    "Download video" : "Descarrega el vídeo",
    "Keyboard shortcut" : "Drecera de teclat",
    "Description" : "Descripció",
    "right" : "dreta",
    "Jump to next article" : "Vés al proper article",
    "left" : "esquerra",
    "Jump to previous article" : "Vés a l'article anterior",
    "Toggle star article" : "Commuta l'article com a destacat",
    "Star article and jump to next one" : "Destaca l'article i vés al següent",
    "Toggle keep current article unread" : "Commuta mantenir de l’article actual com a no llegit",
    "Open article in new tab" : "Obre l'article a una pestanya nova",
    "Toggle expand article in compact view" : "Commuta expandir l'article a una vista compacta",
    "Refresh" : "Refresca",
    "Load next feed" : "Carrega la font següent",
    "Load previous feed" : "Carrega la font anterior",
    "Load previous folder" : "Carrega la carpeta anterior",
    "Load next folder" : "Carrega la carpeta següent",
    "Scroll to active navigation entry" : "Desplaça per activar l'entrada de navegació",
    "Mark current article's feed/folder read" : "Marca com a llegida la font/carpeta de l'article actual",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "S'ha detectat el mode Ajax o webcron. Les vostres fonts no s'actualitzaran!",
    "How to set up the operating system cron" : "Com configurar el cron del sistema operatiu",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Instal·leu i configureu un actualitzador en paral·lel més ràpid que faci servir l'API d'actualització de l'aplicació de Notí­cies",
    "Subscribe" : "Subscriu",
    "Web address" : "Adreça web",
    "Feed exists already!" : "La font ja existeix!",
    "Folder" : "Carpeta",
    "No folder" : "Sense carpeta",
    "New folder" : "Carpeta nova",
    "Folder name" : "Nom de la carpeta",
    "Go back" : "Torna enrere",
    "Folder exists already!" : "La carpeta ja existeix!",
    "Credentials" : "Credencials",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Les credencials d’Autenticació Bàsica d'HTTP s’han d’emmagatzemar sense xifrar. Tothom que tingui accés al servidor o a la base de dades hi podrà accedir!",
    "Password" : "Contrasenya",
    "New Folder" : "Nova carpeta",
    "Create" : "Crea",
    "Explore" : "Explora",
    "Update failed more than 50 times" : "L'actualització ha fallat més de 50 vegades",
    "Deleted feed" : "S'ha suprimit la font",
    "Undo delete feed" : "Desfés la supressió de la font",
    "Rename" : "Canvia el nom",
    "Menu" : "Menú",
    "Mark read" : "Marca com a llegit",
    "Unpin from top" : "Desancora-ho de la part superior",
    "Pin to top" : "Ancora-ho a la part superior",
    "Newest first" : "Més nou primer",
    "Oldest first" : "Més antic primer",
    "Default order" : "Ordre per defecte",
    "Enable full text" : "Activa el text complet",
    "Disable full text" : "Desactiva el text complet",
    "Unread updated" : "Actualització no llegida",
    "Ignore updated" : "Ignora l'actualització",
    "Open feed URL" : "Obre l'URL del canal",
    "Delete" : "Suprimeix",
    "Dismiss" : "Rebutja",
    "Collapse" : "Replega",
    "Deleted folder" : "Carpeta suprimida",
    "Undo delete folder" : "Desfés la supressió de la carpeta",
    "Starred" : "Destacats",
    "All articles" : "Tots els articles",
    "Settings" : "Paràmetres",
    "Disable mark read through scrolling" : "Desactiva la marca de lectura mitjançant el desplaçament",
    "Compact view" : "Vista compacta",
    "Expand articles on key navigation" : "Amplia els articles sobre la navegació per tecles",
    "Show all articles" : "Mostra tots els articles",
    "Reverse ordering (oldest on top)" : "Ordre invers (més antic a la part superior)",
    "Subscriptions (OPML)" : "Subscripcions (OPML)",
    "Import" : "Importa",
    "Export" : "Exporta",
    "Error when importing: File does not contain valid OPML" : "S'ha produït un error mentre s'importava: el fitxer no conté OPML vàlid",
    "Error when importing: OPML is does neither contain feeds nor folders" : "S'ha produït un error mentre s'importava: OPML no conté ni fonts ni carpetes",
    "Unread/Starred Articles" : "Articles no llegits/destacats",
    "Error when importing: file does not contain valid JSON" : "S'ha produït un error mentre s'importava: el fitxer no conté un JSON vàlid",
    "Help" : "Ajuda",
    "Keyboard shortcuts" : "Dreceres de teclat",
    "Documentation" : "Documentació",
    "Report a bug" : "Informa d'un error"
},
"nplurals=2; plural=(n != 1);");
